Welcome to honeybee-display's documentation!
===================================

.. image:: http://www.ladybug.tools/assets/img/honeybee.png

A library that adds methods to translate honeybee objects to VisualizationSets.


Installation
============

``pip install -U honeybee-display``

If you want to also include all dependencies needed to produce VTK visualizations
from honeybee Models use.

``pip install -U honeybee-display[full]``

To check if the command line interface is installed correctly use ``honeybee-display --help``

CLI Docs
=============

For command line interface documentation and API documentation see the pages below.


.. toctree::
   :maxdepth: 2

   cli/index


honeybee_display
=======

.. toctree::
   :maxdepth: 4

   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
